Index: include/core/SkTypeface.h |
diff --git a/include/core/SkTypeface.h b/include/core/SkTypeface.h |
index 61618697e8549fac9c9b98fbc34eb9c9d36cf7ed..b2c288ebcdd0a543e8e4711c4f77913aa1003ae7 100644 |
--- a/include/core/SkTypeface.h |
+++ b/include/core/SkTypeface.h |
@@ -150,9 +150,10 @@ |
#endif |
/** Return a new typeface given font data and configuration. If the data |
- is not valid font data, returns nullptr. |
- */ |
- static sk_sp<SkTypeface> MakeFromFontData(std::unique_ptr<SkFontData>); |
+ is not valid font data, returns nullptr. Ownership of the font data is |
+ transferred, so the caller must not reference it again. |
+ */ |
+ static sk_sp<SkTypeface> MakeFromFontData(SkFontData*); |
/** Write a unique signature to a stream, sufficient to reconstruct a |
typeface referencing the same font when Deserialize is called. |
@@ -299,9 +300,10 @@ |
SkStreamAsset* openStream(int* ttcIndex) const; |
/** |
- * Return the font data, or nullptr on failure. |
- */ |
- std::unique_ptr<SkFontData> makeFontData() const; |
+ * Return the font data, or NULL on failure. |
+ * The caller is responsible for deleting the font data. |
+ */ |
+ SkFontData* createFontData() const; |
/** |
* Return a scalercontext for the given descriptor. If this fails, then |
@@ -359,7 +361,7 @@ |
virtual SkStreamAsset* onOpenStream(int* ttcIndex) const = 0; |
// TODO: make pure virtual. |
- virtual std::unique_ptr<SkFontData> onMakeFontData() const; |
+ virtual SkFontData* onCreateFontData() const; |
virtual void onGetFontDescriptor(SkFontDescriptor*, bool* isLocal) const = 0; |